@@ -169,6 +169,11 @@ def xmr_comparison(df_list, condition, xtick_labels, subplot_titles,
         
         # Plot moving range in the second row
         axes[1, idx].plot(moving_range, marker='o', linestyle=linestyle)
+
+        # Offset moving range by 1 relative to the individual values
+        for xi, yi in zip(xticks, moving_range):
+            if np.isnan(yi):
+                axes[1, idx].plot(xi, 0, marker='x', color='white', markersize=0)
     
         # Add UPL and LPL horizontal lines for moving range plot
         axes[1, idx].axhline(URL, color='red', linestyle='--')
